@@ -4,7 +4,7 @@
 
 //-----------------------------------------------------------------------------
 // Image definitions
-#define IMAGE_FILE_NAME "/home/opt/phototranslator-alpha/image.jpg"
+#define IMAGE_FILE_NAME "/home/user/MyDocs/.images/image.jpg"
 #define IMAGE_FILE_TYPE "JPG"
 
 //-----------------------------------------------------------------------------
